==> language-env_0.64.tar.gz: language-env-0.63/ja/dot.cshrc.pl <==
# s comment -*-coding: euc-jp;-*-
csh NO KIDOU JI NI JIKKOU SAREMASU.
SAMAZAMA NA SETTEI WO SHITEIRU NODE, MEWO TOOSHITE OITE KUDASAI.
END
csh ưȤ˼¹Ԥޤ
ޤޤ򤷤ƤΤǡܤ̤ƤƤ
END
print <<'EOF';
# ----- Ū -----
EOF


print "# XIM С̾\n";
print "# (XIM ϡlanguge-env ǻȤѿǤ)\n";
if ($IM_DEFAULT eq "Canna") {
	print "set XIM=kinput2\n";
} elsif ($IM_DEFAULT eq "Wnn") {
	print "set XIM=kinput2\n";
} elsif ($IM_DEFAULT eq "SKK") {
	print "set XIM=skkinput\n";
} 
if ($IM_HOST{"Canna"} ne "") {
	print "setenv CANNAHOST $IM_HOST{'Canna'}\n";
}
if ($IM_HOST{"Wnn"} ne "") {
	print "setenv JSERVER $IM_HOST{'Wnn'}\n";
}
if ($IM_HOST{"SKK"} ne "") {
	print "setenv JSERVER $IM_HOST{'SKK'}\n";
}


print <<'EOF';
# xprop ϡxbase-clients ѥå˴ޤޤޤ
if ( $?WINDOWID && -x /usr/bin/X11/xprop ) then
  # X Window System äƤ뤱 X Window System ̿븢¤
  # ʤȤ (su Ȥʤ) ؤк
  xprop -id $WINDOWID >& /dev/null || unset WINDOWID
endif
if ( $?WINDOWID && -x /usr/bin/X11/xprop ) then
  set XPROP=`xprop -id $WINDOWID WM_CLASS` >&/dev/null
  set CLASS=`echo $XPROP | sed -e 's/.*WM_CLASS(STRING) = "//' -e 's/[",]//g'`
  switch ("$CLASS")
  case *kterm* :
    set LANG=ja_JP.eucJP ; breaksw
  case *krxvt* :
    set LANG=ja_JP.eucJP ; breaksw
  case *k[aw]term* :
    set LANG=ja_JP.eucJP ; breaksw
  case *UXTerm* :
    set LANG=ja_JP.UTF-8 ; breaksw
  case *hanterm* :
    set LANG=ko_KR.eucKR ; breaksw
  case *caterm* :
    set LANG=zh_TW.Big5 ; breaksw
  case *crxvt-big5* :
    set LANG=zh_TW.Big5 ; breaksw
  case *crxvt-gb* :
    set LANG=zh_CN.GB2312 ; breaksw
  case *[xa]term* :
    set LANG=C ; breaksw
  default:
    breaksw
  endsw
else
  switch ($TERM)
    case linux:
      set LANG=C ; breaksw
    case xterm:
      breaksw
    case jfbterm:
      breaksw
    default:
      set LANG=ja_JP.eucJP
  endsw
endif
switch ($LANG)
  case ja_JP.UTF-8:
    set JLESSCHARSET=utf-8 ; set LV=-Ou8 ; breaksw
  case ja_JP.*:
    set JLESSCHARSET=japanese-euc ; set LV=-Oej ; breaksw
  default:
    set JLESSCHARSET=latin1 ; set LV=-Al1
endsw
setenv LANG $LANG
setenv JLESSCHARSET $JLESSCHARSET
setenv LV $LV
setenv PAGER more
foreach pager ( lv jless less )
  if ( -x /usr/bin/$pager ) then
    setenv PAGER $pager
    break
  endif
end
alias jfbterm '(setenv LANG ja_JP.eucJP ; exec /usr/bin/jfbterm \!*)'
# XMODIFIERS  setenv ʤΤϡemacs  Segmentation Fault 򵯤
# ˡȡDebian ˥塼ƥफεưˤбǤʤ
alias xemacs '(unsetenv XMODIFIERS ; exec \xemacs \!*)'
# perl ˤ󤹤˥󥰤ФͭˤƤ
# setenv PERL_BADLANG 0
EOF

if (!$EXTENDED) {return;}
print <<'EOF';
# ----- ߤ˱ -----
# ls ưman ls 
if ( $TERM == "dumb" || $TERM == "emacs" ) then
  alias ls '/bin/ls -F'
else
  alias ls '/bin/ls -F --color=auto'
endif
# ɸ२ǥ vi ˤ롣Debian Policy Manual 
setenv EDITOR vi
# ץץȡman tcsh 
set promptchars='%#'
set prompt='%B%~%#%b '
# mh 󥹥ȡ뤵Ƥ顢PATH ˲ä롣
[ -x /usr/bin/mh/mhmail ]
if ($status == 0) then
  set path=($path /usr/bin/mh)
endif
# եȤɤ°Ǻ뤫man umask 
umask 022
# less ưman less 
setenv LESS -M
if ( -x /usr/bin/lesspipe ) then
  setenv LESSOPEN "| /usr/bin/lesspipe '%s'"
  setenv LESSCLOSE "/usr/bin/lesspipe '%s' '%s'"
endif
# Ctrl-D ǥȤΤ롣man tcsh 
set ignoreeof
# ȥǥ쥯ȥΥХååץեɽ
# (ݤ "chkbackups | xargs rm" ¹ԤΤ)
alias chkbackups '/usr/bin/find . -name "?*~" -o -name "?*.bak" -o -name ".[^.]?*~" -o -name ".[^.]?*.bak" -maxdepth 1'
# X Window System Ǥ
if ( $?DISPLAY ) then
  # üɥΥȥѹ
  alias xtitle '/bin/echo -e "\033]0;\!*\007\c"'
endif
EOF

==> language-env_0.69.tar.gz: language-env-0.69/ja/dot.cshrc.pl <==
# s comment -*-coding: euc-jp;-*-
csh NO KIDOU JI NI JIKKOU SAREMASU.
SAMAZAMA NA SETTEI WO SHITEIRU NODE, MEWO TOOSHITE OITE KUDASAI.
END
csh ưȤ˼¹Ԥޤ
ޤޤ򤷤ƤΤǡܤ̤ƤƤ
END
print <<'EOF';
# ----- Ū -----
EOF


print "# XIM С̾\n";
print "# (XIM ϡlanguge-env ǻȤѿǤ)\n";
if ($IM_DEFAULT eq "Canna") {
	print "set XIM=kinput2\n";
} elsif ($IM_DEFAULT eq "Wnn") {
	print "set XIM=kinput2\n";
} elsif ($IM_DEFAULT eq "SKK") {
	print "set XIM=skkinput\n";
} 
if ($IM_HOST{"Canna"} ne "") {
	print "setenv CANNAHOST $IM_HOST{'Canna'}\n";
}
if ($IM_HOST{"Wnn"} ne "") {
	print "setenv JSERVER $IM_HOST{'Wnn'}\n";
}
if ($IM_HOST{"SKK"} ne "") {
	print "setenv JSERVER $IM_HOST{'SKK'}\n";
}


print <<'EOF';
# xprop ϡxbase-clients ѥå˴ޤޤޤ
if ( $?WINDOWID && -x /usr/bin/X11/xprop ) then
  # X Window System äƤ뤱 X Window System ̿븢¤
  # ʤȤ (su Ȥʤ) ؤк
  xprop -id $WINDOWID >& /dev/null || unset WINDOWID
endif
if ( $?WINDOWID && -x /usr/bin/X11/xprop ) then
  set XPROP=`xprop -id $WINDOWID WM_CLASS` >&/dev/null
  set CLASS=`echo $XPROP | sed -e 's/.*WM_CLASS(STRING) = "//' -e 's/[",]//g'`
  switch ("$CLASS")
  case *kterm* :
    set LANG=ja_JP.EUC-JP ; breaksw
  case *krxvt* :
    set LANG=ja_JP.EUC-JP ; breaksw
  case *k[aw]term* :
    set LANG=ja_JP.EUC-JP ; breaksw
  case *UXTerm* :
    set LANG=ja_JP.UTF-8 ; breaksw
  case *hanterm* :
    set LANG=ko_KR.eucKR ; breaksw
  case *caterm* :
    set LANG=zh_TW.Big5 ; breaksw
  case *crxvt-big5* :
    set LANG=zh_TW.Big5 ; breaksw
  case *crxvt-gb* :
    set LANG=zh_CN.GB2312 ; breaksw
  case *[xa]term* :
    set LANG=C ; breaksw
  default:
    breaksw
  endsw
else
  switch ($TERM)
    case linux:
      set LANG=C ; breaksw
    case xterm:
      breaksw
    case jfbterm:
      breaksw
    default:
      set LANG=ja_JP.EUC-JP
  endsw
endif
switch ($LANG)
  case ja_JP.UTF-8:
    set JLESSCHARSET=utf-8 ; set LV=-Ou8 ; breaksw
  case ja_JP.*:
    set JLESSCHARSET=japanese-euc ; set LV=-Oej ; breaksw
  default:
    set JLESSCHARSET=latin1 ; set LV=-Al1
endsw
setenv LANG $LANG
setenv JLESSCHARSET $JLESSCHARSET
setenv LV $LV
setenv PAGER more
foreach pager ( lv jless less )
  if ( -x /usr/bin/$pager ) then
    setenv PAGER $pager
    break
  endif
end
alias jfbterm '(setenv LANG ja_JP.EUC-JP ; exec /usr/bin/jfbterm \!*)'
# XMODIFIERS  setenv ʤΤϡemacs  Segmentation Fault 򵯤
# ˡȡDebian ˥塼ƥफεưˤбǤʤ
alias xemacs '(unsetenv XMODIFIERS ; exec \xemacs \!*)'
# perl ˤ󤹤˥󥰤ФͭˤƤ
# setenv PERL_BADLANG 0
EOF

if (!$EXTENDED) {return;}
print <<'EOF';
# ----- ߤ˱ -----
# ls ưman ls 
if ( $TERM == "dumb" || $TERM == "emacs" ) then
  alias ls '/bin/ls -F'
else
  alias ls '/bin/ls -F --color=auto'
endif
# ɸ२ǥ vi ˤ롣Debian Policy Manual 
setenv EDITOR vi
# ץץȡman tcsh 
set promptchars='%#'
set prompt='%B%~%#%b '
# mh 󥹥ȡ뤵Ƥ顢PATH ˲ä롣
[ -x /usr/bin/mh/mhmail ]
if ($status == 0) then
  set path=($path /usr/bin/mh)
endif
# եȤɤ°Ǻ뤫man umask 
umask 022
# less ưman less 
setenv LESS -M
if ( -x /usr/bin/lesspipe ) then
  setenv LESSOPEN "| /usr/bin/lesspipe '%s'"
  setenv LESSCLOSE "/usr/bin/lesspipe '%s' '%s'"
endif
# Ctrl-D ǥȤΤ롣man tcsh 
set ignoreeof
# ȥǥ쥯ȥΥХååץեɽ
# (ݤ "chkbackups | xargs rm" ¹ԤΤ)
alias chkbackups '/usr/bin/find . -name "?*~" -o -name "?*.bak" -o -name ".[^.]?*~" -o -name ".[^.]?*.bak" -maxdepth 1'
# X Window System Ǥ
if ( $?DISPLAY ) then
  # üɥΥȥѹ
  alias xtitle '/bin/echo -e "\033]0;\!*\007\c"'
endif
EOF
